#!/bin/sh
#
# source:http://ftp.gnome.org/pub/gnome/sources/network-manager-applet/0.9/network-manager-applet-0.9.2.0.tar.xz
#
# maintainer: Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#

#------------------Set Some Variables

buildir=$(pwd)
soft="network-manager-applet"
softversion="0.9.2.0"
packageversion="72.2"
arch="i486"
cpu="i686"
srcpkg="$buildir/$soft-$softversion.tar.xz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://ftp.gnome.org/pub/GNOME/sources/network-manager-applet/0.9/$soft-$softversion.tar.xz

# -----------------Extract sources and get ready to build

# check if source is present
if [ -f $soft-$softversion.tar.xz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.txz
rm -rf $dest
(
cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
    --prefix=/usr \
    --sysconfdir=/etc \
    --localstatedir=/var \
    --mandir=/usr/man \
    --disable-static \
    --disable-schemas-install \
    --with-gconf-source="xml::/etc/gconf/gconf.xml.defaults"

make -j6
make install DESTDIR=$dest

sed -i -e "s/Icon=.*/Icon=gnome-network-preferences/g" $dest/usr/share/applications/nm-connection-editor.desktop
sed -i -e "s/OnlyShowIn=GNOME/OnlyShowIn=GNOME;XFCE/g" $dest/usr/share/applications/nm-connection-editor.desktop
sed -i -e "s/Categories=GNOME;GTK;Settings;X-GNOME-NetworkSettings;/Categories=System;X-GNOME-NetworkSettings;X-Zenpanel;X-XFCE-SettingsDialog;X-XFCE-HardwareSettings;/g" $dest/usr/share/applications/nm-connection-editor.desktop	

#------------------- gconf stuff

export GCONF_CONFIG_SOURCE="xml::$dest/etc/gconf/gconf.xml.defaults"
if [ -d $dest/etc/gconf/schemas ]; then
     install -v -d -m755 $dest/etc/gconf/gconf.xml.defaults
     SCHEMAS=$dest/etc/gconf/schemas
     for schema in $SCHEMAS/*.schemas; do
        gconftool-2 --makefile-install-rule $schema
     done
# Reset / Verify correct permissions
     ( cd $dest/etc/gconf ; find . -type d -exec chmod 755 {} \; )
     ( cd $dest/etc/gconf ; find . -type f -exec chmod 644 {} \; )
fi

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  ChangeLog CONTRIBUTING COPYING INSTALL \
$dest/usr/doc/$soft-$softversion

# create the split package for libraries who need dependencies
cd $buildir
mkdir -p $soft-bluetooth-$softversion-$arch-$packageversion/usr/lib/gnome-bluetooth/plugins/
mkdir -p $soft-bluetooth-$softversion-$arch-$packageversion/install
cat <<EOF > $soft-bluetooth-$softversion-$arch-$packageversion/install/slack-desc
                                |-----handy-ruler------------------------------------------------------|
network-manager-applet-bluetooth: network-manager-applet-bluetooth - bluetooth support
network-manager-applet-bluetooth:
network-manager-applet-bluetooth: Bluetooth support in the NetworkManager
network-manager-applet-bluetooth: 
network-manager-applet-bluetooth: 
network-manager-applet-bluetooth: 
network-manager-applet-bluetooth: 
network-manager-applet-bluetooth:
network-manager-applet-bluetooth:
network-manager-applet-bluetooth:
network-manager-applet-bluetooth:
EOF

mv -v $dest/usr/lib/gnome-bluetooth/plugins/libnma.so $soft-bluetooth-$softversion-$arch-$packageversion/usr/lib/gnome-bluetooth/plugins
rm -rf $dest/usr/lib/gnome-bluetooth

echo "create the bluetooth package"
cd $soft-bluetooth-$softversion-$arch-$packageversion
makepkg -l y -c n $buildir/$soft-bluetooth-$softversion-$arch-$packageversion.txz
cd ..
echo "generate md5sum for bluetooth package"
md5sum $soft-bluetooth-$softversion-$arch-$packageversion.txz > $package.md5
rm -rf $soft-bluetooth-$softversion-$arch-$packageversion

#------------------ make a slack-desc file

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

                      |-----handy-ruler------------------------------------------|
network-manager-applet: network-manager-applet - The GNOME network-manager-applet
network-manager-applet:
network-manager-applet: nm-applet is a gui frontend for NetworkManager.
network-manager-applet:
network-manager-applet:
network-manager-applet:
network-manager-applet:
network-manager-applet:
network-manager-applet:
network-manager-applet:
network-manager-applet:
EODESC

cat << DOINST > $dest/install/doinst.sh
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi
DOINST

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5
) 2>&1 | tee $soft-$softversion.log
